# Generated by Django 4.0.3 on 2022-03-20 19:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_quotes', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='sourcegroup',
            name='name',
            field=models.CharField(db_index=True, help_text='A source for individuals making the quotes. Use as an abstract grouping.', max_length=50, verbose_name='Source Name'),
        ),
    ]
