{% extends "base.html" %}
{% load i18n %}
{% block extratitle %}{% blocktranslate %}Delete quote{% endblocktranslate %} - {% endblock %}
{% block content %}
          <nav aria-label="breadcrumb">
  <ol class="breadcrumb">
    <li class="breadcrumb-item"><a href="{% url 'quotes:group_list' %}">{% translate "Groups" %}</a></li>
    <li class="breadcrumb-item"><a href="{% url 'quotes:group_detail' group=object.source.group.slug %}">{{ object.source.group.name }}</a></li>
    <li class="breadcrumb-item"><a href="{% url 'quotes:source_list' group=object.source.group.slug %}">{% translate "Sources" %}</a></li>
    <li class="breadcrumb-item"><a href="{% url 'quotes:source_detail' source=object.source.slug %}">{{ object.source.name }}</a></li>
    <li class="breadcrumb-item"><a href="{% url 'quotes:quote_list' source=object.source.slug %}">{% translate "Quotes" %}</a></li>
    <li class="breadcrumb-item"><a href="{% url 'quotes:quote_detail' quote=object.id %}">{{ object.id }}</a></li>
    <li class="breadcrumb-item active" aria-current="page">{% translate "Delete" %}</li>
  </ol>
  </nav>
<h1>{% blocktranslate %}Delete this quote from{% endblocktranslate %} {{ object.source.name }}</h1>
  <p><strong>{% translate "Are you sure you want to delete this?" %}</strong></p>
  <blockquote>{{ quote.quote_rendered|safe }}</blockquote>
<form method="post">{% csrf_token %}
<button class="btn btn-danger" type="submit">{% translate "Delete quote" %}</button> <a href="{% url "quotes:quote_list" source=object.source.slug %}" class="btn btn-secondary">{% translate "Return to quote list" %}</a>
</form>
{% endblock %}
