# Generated by Django 4.0.3 on 2022-03-20 20:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_quotes', '0002_alter_sourcegroup_name'),
    ]

    operations = [
        migrations.AlterField(
            model_name='source',
            name='slug',
            field=models.SlugField(blank=True, editable=False, help_text='Global slug of the character, will be auto generated from name and group if not overridden.', max_length=250, unique=True),
        ),
        migrations.AlterField(
            model_name='sourcegroup',
            name='slug',
            field=models.SlugField(blank=True, editable=False, help_text='Unique slug for this group.', max_length=70, unique=True),
        ),
    ]
