{% extends "base.html" %}
{% load i18n crispy_forms_filters %}
{% block extratitle %}{% trans "Add new source to" %} {{ group.name }} - {% endblock %}
{% block content %}
   <nav aria-label="breadcrumb">
  <ol class="breadcrumb">
    <li class="breadcrumb-item"><a href="{% url 'quotes:group_list' %}">{% translate "Groups" %}</a></li>
    <li class="breadcrumb-item"><a href="{% url 'quotes:group_detail' group=group.slug %}">{{ group.name }}</a></li>
    <li class="breadcrumb-item"><a href="{% url 'quotes:source_list' group=group.slug %}">{% translate "Sources" %}</a></li>
    <li class="breadcrumb-item active" aria-current="page">{% translate "Add source" %}</li>
  </ol>
  </nav>
<h1>{% translate "Add source to" %} {{ group.name }}</h1>
  <p>{% blocktranslate %}Add a character to {% endblocktranslate %} {{ group.name }} {% blocktranslate %}using the form below.{% endblocktranslate %}</p>
  <form method="post">{% csrf_token %}
  {{ form|crispy }}
  <button type="submit" class="btn btn-success">{% translate "Add source" %}</button> <a href="{% url 'quotes:source_list' group=group.slug %}" class="btn btn-secondary">{% translate "Back to source list" %}</a>
  </form>
{% endblock %}
